# coding: utf-8

"""
    ACROSS Server

    Server providing tools and utilities for various NASA missions to aid in coordination of large observation efforts.

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FrequencyUnit(str, Enum):
    """
    Enum to represent the bandpass frequency types
    """

    """
    allowed enum values
    """
    HZ = 'Hz'
    KHZ = 'kHz'
    MHZ = 'MHz'
    GHZ = 'GHz'
    THZ = 'THz'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FrequencyUnit from a JSON string"""
        return cls(json.loads(json_str))


